package com.zanxiang.game.data.serve.task;

import com.zanxiang.game.data.serve.service.IGameMonitorAlarmService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.cloud.context.config.annotation.RefreshScope;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.scheduling.concurrent.ThreadPoolTaskScheduler;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.concurrent.*;

/**
 * @author tianhua
 * @version 1.0
 * @description: 游戏监控告警定时任务
 * @date 2023/12/13 19:08
 */
@Slf4j
@Component
@RefreshScope
public class GameMonitorAlarmTask {

    @Autowired
    private IGameMonitorAlarmService gameMonitorAlarmService;

    private ExecutorService taskScheduler = Executors.newSingleThreadExecutor();


    @Value("${sys-config.task_is_run}")
    private boolean run;

    /**
     * 任务每5分钟运行一次
     */
    @Scheduled(cron = "0 */5 * * * *")
    public void run() {
        log.info("游戏监控告警定时任务开始.");
        log.info("run{}", run);
        Future<?> future =  taskScheduler.submit(()->{
            try {
                log.info("游戏监控在线程里开始执行");
                if (!run) {
                    log.info("游戏监控告警定时任务本地不执行.");
                    return;
                }
                try {
                    log.info("进入告警方法");
                    gameMonitorAlarmService.sendMsgToUser();
                    log.info("游戏监控告警定时任务结束.");
                } catch (Exception e) {
                    log.info("定时任务游戏监控告警出错", e);
                }
            }catch (Exception e){
                log.error("定时任务游戏监控告警出错", e);
            }
        });
        try {
            //两分钟执行不完就超时
            future.get(120, TimeUnit.SECONDS);
        } catch (Exception e) {
            log.error("定时任务游戏监控告警超时", e);
            future.cancel(true);
        }
    }


}
